@@ -73,7 +73,7 @@ sub commit_sql {
             my $tp = Term::TablePrint->new( $sf->{o}{table} );
             $tp->print_table(
                 $all_arrayref,
-                { info => $info, prompt => $prompt, max_rows => 0, footer => $sf->{d}{table_footer} }
+                { info => $info, prompt => $prompt, footer => $sf->{d}{table_footer} }
             );
         }
         $ax->print_sql_info( $info, $waiting );
